@@ -4,12 +4,13 @@ import joblib
 import numpy as np
 from pkg_resources import resource_filename
 import fire
+import warnings
 
 
 class Regbot:
   reg_model_path = resource_filename(__name__, 'btc_model.h5') 
   model_scaler_path = resource_filename(__name__, 'btclogscaler.gz') 
-  thr = 0.49503654254794244
+  thr = 0.5047668309213305 #0.49503654254794244
 
   def __init__(self,*args):
   	pass
@@ -46,9 +47,12 @@ class Regbot:
 
 
 
+
 def signal(opening, closing,utcdatetime):
   try:
-    return Regbot.buySignalGenerator(opening,closing,utcdatetime)
+    with warnings.catch_warnings():
+        warnings.filterwarnings("ignore")
+        return Regbot.buySignalGenerator(opening,closing,utcdatetime)
   except Exception as e:
     print(e)
 
